@@ -12,7 +12,7 @@ class BinaryCrossentropy(BaseLoss):
         axis=-1,
         reduction="auto",
         name="bce_loss",
-    ):
+    ) -> None:
         super().__init__(name)
         self._loss = TF_BCE(
             from_logits=from_logits,
@@ -23,22 +23,34 @@ class BinaryCrossentropy(BaseLoss):
 
     def discriminator_loss(
         self, discriminator, target_true, target_pred, sample_weight=None
-    ):
-        y_true = discriminator(target_true)
-        y_pred = discriminator(target_pred)
+    ) -> tf.Tensor:
+        rnd_true = tf.random.normal(
+            tf.shape(target_true), stddev=0.05, dtype=target_true.dtype
+        )
+        y_true = discriminator(target_true + rnd_true, training=True)
         loss_real = self._loss(
             tf.ones_like(y_true), y_true, sample_weight=sample_weight
         )
+        loss_real = tf.cast(loss_real, dtype=target_true.dtype)
+        rnd_pred = tf.random.normal(
+            tf.shape(target_pred), stddev=0.05, dtype=target_pred.dtype
+        )
+        y_pred = discriminator(target_pred + rnd_pred, training=True)
         loss_fake = self._loss(
             tf.zeros_like(y_pred), y_pred, sample_weight=sample_weight
         )
-        return loss_real + loss_fake
+        loss_fake = tf.cast(loss_fake, dtype=target_pred.dtype)
+        return (loss_real + loss_fake) / 2.0
 
     def transformer_loss(
         self, discriminator, target_true, target_pred, sample_weight=None
-    ):
-        y_pred = discriminator(target_pred)
+    ) -> tf.Tensor:
+        rnd_pred = tf.random.normal(
+            tf.shape(target_pred), stddev=0.05, dtype=target_pred.dtype
+        )
+        y_pred = discriminator(target_pred + rnd_pred, training=False)
         loss_fake = self._loss(
             tf.ones_like(y_pred), y_pred, sample_weight=sample_weight
         )
+        loss_fake = tf.cast(loss_fake, dtype=target_pred.dtype)
         return loss_fake
